import React, { useEffect, useState } from 'react';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".index_segmented-control-container__2yxAR {\n  width: 170px;\n  text-align: center;\n  height: 38px;\n  -webkit-box-sizing: border-box;\n  box-sizing: border-box;\n  direction: ltr;\n  display: table;\n}\n\n.index_segmented-control-container__2yxAR > ul {\n  display: table-row;\n  display: -webkit-box;\n  display: -ms-flexbox;\n  display: flex;\n  padding: 6px 8px;\n  background: #efeef5;\n  border-radius: 30px;\n  gap: 2px;\n}\n\n.index_segmented-control-container__2yxAR > ul > li {\n  background: #fff;\n  border: 1px solid;\n  border-right: none;\n  font-size: 13px;\n  height: 26px;\n  cursor: pointer;\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n  -webkit-box-sizing: border-box;\n  box-sizing: border-box;\n  vertical-align: middle;\n  display: table-cell;\n  display: -webkit-box;\n  display: -ms-flexbox;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  -ms-flex: auto;\n  flex: auto;\n}\n\n.index_segmented-control-container__2yxAR > ul > li.index_disabled__QIknV {\n  background: white !important;\n  color: #717171 !important;\n  opacity: 0.5;\n  cursor: not-allowed;\n}\n\n.index_segmented-control-container__2yxAR > ul > li {\n  background: transparent !important;\n  border-color: #efeef5 !important;\n  color: #717171;\n  border-radius: 30px;\n  padding: 5px 10px;\n  min-width: 60px;\n}\n\n.index_segmented-control-container__2yxAR > ul > li.index_selected__28vKH {\n  background: white !important;\n  color: #717171 !important;\n  font-weight: bold;\n  box-shadow: 0 3px 6px 0 rgb(0 0 0 / 16%);\n}\n";
styleInject(css_248z);

var _excluded = ["segments", "onChangeSegment"];
/**if no default property is set, the default selected segment is automatically the first encountered  */

var SegmentedControl = function SegmentedControl(_ref) {
  var _segments$find$value, _segments$find;

  var segments = _ref.segments,
      onChangeSegment = _ref.onChangeSegment,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  useEffect(function () {
    var uniqueKeys = new Set(segments.map(function (_ref2) {
      var value = _ref2.value;
      return value;
    }));

    if (uniqueKeys.size !== segments.length) {
      throw new Error('Segments must have unique values');
    }
  }, [segments]);

  var _useState = useState((_segments$find$value = (_segments$find = segments.find(function (s) {
    return s["default"];
  })) == null ? void 0 : _segments$find.value) != null ? _segments$find$value : segments[0].value),
      selectedSegment = _useState[0],
      setSelectedSegment = _useState[1];

  var onChange = function onChange(selectedSegment) {
    setSelectedSegment(selectedSegment);
    onChangeSegment(selectedSegment);
  };

  var renderSegments = function renderSegments() {
    return segments.map(function (segment) {
      if (segment.value === selectedSegment) {
        var _segment$label;

        return React.createElement("li", {
          key: segment.value,
          className: "selected"
        }, (_segment$label = segment == null ? void 0 : segment.label) != null ? _segment$label : '');
      }

      if (segment.disabled) {
        var _segment$label2;

        return React.createElement("li", {
          key: segment.value,
          className: "disabled"
        }, (_segment$label2 = segment == null ? void 0 : segment.label) != null ? _segment$label2 : '');
      }

      return React.createElement("li", {
        key: segment.value,
        onClick: function onClick() {
          return onChange(segment.value);
        }
      }, segment.label);
    });
  };

  return React.createElement("div", Object.assign({
    className: "segmented-control-container"
  }, props), React.createElement("ul", null, renderSegments()));
};

export { SegmentedControl };
//# sourceMappingURL=ios-segmented-control-react.esm.js.map
